apply function
Future<List<AppliedPatch> >
apply(
- BuildInput input,
- BuildOutputBuilder output, {
- required String package,
Applies the committed Patchwork patch for package from a build hook.
If the package is already applied and pub resolution already points at the generated Patchwork output, this is a no-op. Other Patchwork safety failures are surfaced as build failures.
Implementation
Future<List<AppliedPatch>> apply(
BuildInput input,
BuildOutputBuilder output, {
required String package,
}) {
return _wrapPatchworkErrors(() => _apply(input, output, package: package));
}