PatchWriteStatus enum
How patchwork commit changed the committed patch artifact.
Values
- written → const PatchWriteStatus
-
A patch file was written or replaced because the edit changed the source.
- unchanged → const PatchWriteStatus
-
The edit matched the existing patch artifact and no file changed.
- removed → const PatchWriteStatus
-
The edit matched the source, so the committed patch artifact was removed.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PatchWriteStatus> - A constant List of the values in this enum, in order of their declaration.